==> dojo-1.9.4.tgz: package/cldr/nls/de/buddhist.js <==
define(
//begin v1.x content
{
	"field-dayperiod": "Tageshälfte",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y G",
	"dayPeriods-format-wide-pm": "nachm.",
	"field-minute": "Minute",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-day-relative+-1": "Gestern",
	"field-weekday": "Wochentag",
	"field-day-relative+-2": "Vorgestern",
	"days-standAlone-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-era": "Epoche",
	"dateFormatItem-Gy": "y G",
	"field-hour": "Stunde",
	"dayPeriods-format-wide-am": "vorm.",
	"dateFormatItem-y": "y G",
	"dateFormatItem-yyyy": "y G",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mär",
		"Apr",
		"Mai",
		"Jun",
		"Jul",
		"Aug",
		"Sep",
		"Okt",
		"Nov",
		"Dez"
	],
	"dateFormatItem-Ed": "E, d.",
	"field-day-relative+0": "Heute",
	"field-day-relative+1": "Morgen",
	"days-standAlone-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"eraAbbr": [
		"BE"
	],
	"field-day-relative+2": "Übermorgen",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"dateFormat-long": "d. MMMM y G",
	"field-zone": "Zone",
	"field-week-relative+-1": "Letzte Woche",
	"dateFormat-medium": "dd.MM.y G",
	"field-year-relative+0": "Dieses Jahr",
	"field-year-relative+1": "Nächstes Jahr",
	"quarters-standAlone-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"field-year-relative+-1": "Letztes Jahr",
	"field-year": "Jahr",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-week": "Woche",
	"months-standAlone-wide": [
		"Januar",
		"Februar",
		"März",
		"April",
		"Mai",
		"Juni",
		"Juli",
		"August",
		"September",
		"Oktober",
		"November",
		"Dezember"
	],
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"dateFormatItem-yyyyMd": "d.M.y GGGGG",
	"dateFormatItem-yyyyMEd": "E, d.M.y GGGGG",
	"field-week-relative+0": "Diese Woche",
	"dateFormatItem-MMMd": "d. MMM",
	"field-week-relative+1": "Nächste Woche",
	"months-format-abbr": [
		"Jan.",
		"Feb.",
		"Mär.",
		"Apr.",
		"Mai",
		"Juni",
		"Juli",
		"Aug.",
		"Sep.",
		"Okt.",
		"Nov.",
		"Dez."
	],
	"field-month-relative+0": "Dieser Monat",
	"field-month": "Monat",
	"field-month-relative+1": "Nächster Monat",
	"dateFormatItem-H": "HH 'Uhr'",
	"days-format-abbr": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"days-format-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"field-second": "Sekunde",
	"dateFormatItem-GyMMMEd": "E, d. MMM y G",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-day": "Tag",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormatItem-MEd": "E, d.M.",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"days-standAlone-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"days-standAlone-abbr": [
		"So",
		"Mo",
		"Di",
		"Mi",
		"Do",
		"Fr",
		"Sa"
	],
	"dateFormat-short": "dd.MM.yy GGGGG",
	"dateFormatItem-yyyyM": "M.y GGGGG",
	"dateFormat-full": "EEEE, d. MMMM y G",
	"dateFormatItem-Md": "d.M.",
	"months-format-wide": [
		"Januar",
		"Februar",
		"März",
		"April",
		"Mai",
		"Juni",
		"Juli",
		"August",
		"September",
		"Oktober",
		"November",
		"Dezember"
	],
	"days-format-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-month-relative+-1": "Letzter Monat",
	"quarters-format-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"days-format-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	]
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/de/buddhist.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "jetzt",
	"field-weekday": "Wochentag",
	"field-wed-relative+0": "diesen Mittwoch",
	"field-wed-relative+1": "nächsten Mittwoch",
	"dateFormatItem-GyMMMEd": "E, d. MMM y G",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-tue-relative+-1": "letzten Dienstag",
	"days-format-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"dateFormat-long": "d. MMMM y G",
	"field-fri-relative+-1": "letzten Freitag",
	"field-wed-relative+-1": "letzten Mittwoch",
	"months-format-wide": [
		"Januar",
		"Februar",
		"März",
		"April",
		"Mai",
		"Juni",
		"Juli",
		"August",
		"September",
		"Oktober",
		"November",
		"Dezember"
	],
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dayPeriods-format-wide-pm": "nachm.",
	"dateFormat-full": "EEEE, d. MMMM y G",
	"dateFormatItem-yyyyMEd": "E, d.M.y GGGGG",
	"field-thu-relative+-1": "letzten Donnerstag",
	"dateFormatItem-Md": "d.M.",
	"dayPeriods-format-wide-noon": "mittags",
	"field-era": "Epoche",
	"months-standAlone-wide": [
		"Januar",
		"Februar",
		"März",
		"April",
		"Mai",
		"Juni",
		"Juli",
		"August",
		"September",
		"Oktober",
		"November",
		"Dezember"
	],
	"quarters-format-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"field-year": "Jahr",
	"field-hour": "Stunde",
	"months-format-abbr": [
		"Jan.",
		"Feb.",
		"März",
		"Apr.",
		"Mai",
		"Juni",
		"Juli",
		"Aug.",
		"Sep.",
		"Okt.",
		"Nov.",
		"Dez."
	],
	"field-sat-relative+0": "diesen Samstag",
	"field-sat-relative+1": "nächsten Samstag",
	"field-day-relative+0": "heute",
	"field-thu-relative+0": "diesen Donnerstag",
	"field-day-relative+1": "morgen",
	"field-thu-relative+1": "nächsten Donnerstag",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "übermorgen",
	"dateFormatItem-H": "HH 'Uhr'",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mär",
		"Apr",
		"Mai",
		"Jun",
		"Jul",
		"Aug",
		"Sep",
		"Okt",
		"Nov",
		"Dez"
	],
	"quarters-standAlone-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y G",
	"days-standAlone-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-sun-relative+0": "diesen Sonntag",
	"field-sun-relative+1": "nächsten Sonntag",
	"eraAbbr": [
		"BE"
	],
	"field-minute": "Minute",
	"field-dayperiod": "Tageshälfte",
	"days-standAlone-abbr": [
		"So",
		"Mo",
		"Di",
		"Mi",
		"Do",
		"Fr",
		"Sa"
	],
	"field-day-relative+-1": "gestern",
	"field-day-relative+-2": "vorgestern",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, d.M.",
	"field-fri-relative+0": "diesen Freitag",
	"field-fri-relative+1": "nächsten Freitag",
	"field-day": "Tag",
	"days-format-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"field-zone": "Zeitzone",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "letztes Jahr",
	"field-month-relative+-1": "letzten Monat",
	"days-format-abbr": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"days-format-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"dateFormatItem-yyyyMd": "d.M.y GGGGG",
	"field-month": "Monat",
	"days-standAlone-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"field-tue-relative+0": "diesen Dienstag",
	"field-tue-relative+1": "nächsten Dienstag",
	"dayPeriods-format-wide-am": "vorm.",
	"field-mon-relative+0": "diesen Montag",
	"field-mon-relative+1": "nächsten Montag",
	"dateFormat-short": "dd.MM.yy GGGGG",
	"field-second": "Sekunde",
	"field-sat-relative+-1": "letzten Samstag",
	"field-sun-relative+-1": "letzten Sonntag",
	"field-month-relative+0": "diesen Monat",
	"field-month-relative+1": "nächsten Monat",
	"dateFormatItem-Ed": "E, d.",
	"field-week": "Woche",
	"dateFormat-medium": "dd.MM.y G",
	"field-year-relative+0": "dieses Jahr",
	"field-week-relative+-1": "letzte Woche",
	"dateFormatItem-yyyyM": "M.y GGGGG",
	"field-year-relative+1": "nächstes Jahr",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "letzten Montag",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "diese Woche",
	"field-week-relative+1": "nächste Woche"
}
//end v1.x content
);
